| Title: | Gene and Exon Data from Ensembl |
|---|---|
| Description: | Gene and exon information from Ensembl genome builds GRCh38.p13 (104) and GRCh37 (v40) to use with the 'topr' package. |
| Authors: | Thorhildur Juliusdottir [cph, aut, cre], Andri Stefansson [aut] |
| Maintainer: | Thorhildur Juliusdottir <[email protected]> |
| License: | LGPL (>= 3) |
| Version: | 1.0.2 |
| Built: | 2026-05-16 09:28:39 UTC |
| Source: | https://github.com/cran/toprdata |
https://www.ensembl.info/2021/05/05/ensembl-104-has-been-released/
ENSEXONSENSEXONS
A data frame with 40,122 rows and 7 variables:
Chromosome on build version 38 (GRCh38/hg38)
genetic position of gene start on build version 38
genetic position of gene end on build version 38
The name of the gene
genetic positions of exon start
genetic position of exon end
exons on chrY and chrM were excluded from the exon dataset
exons on chrY and chrM were excluded from the exon dataset
ENSEXONS_37ENSEXONS_37
A data frame with 62,739 rows and 7 variables:
Chromosome on build version 38 (GRCh38/hg38)
genetic position of gene start on build version 38
genetic position of gene end on build version 38
The name of the gene
genetic positions of exon start
genetic position of exon end
https://www.ensembl.info/2021/05/05/ensembl-104-has-been-released/
ENSGENESENSGENES
A data frame with 40,122 rows and 5 variables:
Chromosome on build version 38 (GRCh38/hg38)
genetic position of gene start on build version 38
genetic position of gene end on build version 38
The name of the gene
the biotype of the gene
genes on chrY and chrM were excluded
genes on chrY and chrM were excluded
ENSGENES_37ENSGENES_37
A data frame with 62,743 rows and 5 variables:
Chromosome on build version 38 (GRCh38/hg38)
genetic position of gene start on build version 38
genetic position of gene end on build version 38
The name of the gene
the biotype of the gene
Gene and exon datasets to use with the 'topr' package
The two datasets are:
ENSGENES Gene information from genome build GRCh38
ENSEXONS Exon information from genome build GRCh38
ENSGENES_37 Gene information from genome build GRCh37
ENSEXONS_37 Exon information from genome build GRCh37
library(toprdata) head(ENSGENES) head(ENSEXONS)library(toprdata) head(ENSGENES) head(ENSEXONS)